@@ -66,4 +66,22 @@ if [ "${NETFILTER_MODE}" == "IPTABLES" ]; then
 
 fi
 
-${COMMAND_ECHO} "Exit success."
+RESULT="${FIREWALL_MODE}|"
+
+if [ "${FIREWALL_MODE}" == "FIREWALLD" ]; then
+
+  ${COMMAND_FIREWALL_CMD} --zone=trusted --remove-interface="${TAP_INTERFACE}"
+
+elif [ "${FIREWALL_MODE}" == "UFW" ]; then
+
+  OUT=$(${COMMAND_UFW} route deny in on ${TAP_INTERFACE})
+
+  RESULT="${RESULT}${OUT}|"
+
+  OUT=$(${COMMAND_UFW} route deny out on ${TAP_INTERFACE})
+
+  RESULT="${RESULT}${OUT}|"
+
+fi
+
+${COMMAND_ECHO} "${RESULT}Exit success."
